@@ -1,6 +1,5 @@
 /*
- *  Copyright (C) 2005-2020 Team Kodi
- *  https://kodi.tv
+ *  Copyright (C) 2005-2021 Team Kodi (https://kodi.tv)
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  *  See LICENSE.md for more information.
@@ -553,7 +552,7 @@ PVR_ERROR Admin::GetDriveSpace(uint64_t& iTotal, uint64_t& iUsed, std::vector<st
   iTotal = totalKb;
   iUsed = totalKb - freeKb;
 
-  Logger::Log(LEVEL_INFO, "%s Space Total: %lld, Used %lld", __func__, iTotal, iUsed);
+  Logger::Log(LEVEL_DEBUG, "%s Space Total: %lld, Used %lld", __func__, iTotal, iUsed);
 
   return PVR_ERROR_NO_ERROR;
 }
